summaryrefslogtreecommitdiffstats
path: root/src/3rdparty/libmng/libmng.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/3rdparty/libmng/libmng.h')
-rw-r--r--src/3rdparty/libmng/libmng.h36
1 files changed, 18 insertions, 18 deletions
diff --git a/src/3rdparty/libmng/libmng.h b/src/3rdparty/libmng/libmng.h
index 0284f1cb3..f9e7d525a 100644
--- a/src/3rdparty/libmng/libmng.h
+++ b/src/3rdparty/libmng/libmng.h
@@ -41,8 +41,8 @@
/* * * */
/* * Parts of this software have been adapted from the libpng package. * */
/* * Although this library supports all features from the PNG specification * */
-/* * (as MNG descends from it) it does not retquire the libpng package. * */
-/* * It does retquire the zlib library and optionally the IJG jpeg library, * */
+/* * (as MNG descends from it) it does not require the libpng package. * */
+/* * It does require the zlib library and optionally the IJG jpeg library, * */
/* * and/or the "little-cms" library by Marti Maria (depending on the * */
/* * inclusion of support for JNG and Full-Color-Management respectively. * */
/* * * */
@@ -425,7 +425,7 @@ MNG_EXT mng_retcode MNG_DECL mng_cleanup (mng_handle* hHandle);
/* use mng_read if you simply want to read a Network Graphic */
/* mng_read_resume is used in I/O-read-suspension scenarios, where the
"readdata" callback may return FALSE & length=0 indicating it's buffer is
- depleted or too short to supply the retquired bytes, and the buffer needs
+ depleted or too short to supply the required bytes, and the buffer needs
to be refilled; libmng will return the errorcode MNG_NEEDMOREDATA telling
the app to refill it's read-buffer after which it must call mng_read_resume
(or mng_display_resume if it also displaying the image simultaneously) */
@@ -574,14 +574,14 @@ MNG_EXT mng_retcode MNG_DECL mng_setcb_processterm (mng_handle hHandle,
it's output device (eg. in Win32 this would mean sending an
invalidate message for the specified region */
/* NOTE that the update-region is specified as x,y,width,height; eg. the
- invalidate message for Windows retquires left,top,right,bottom parameters
+ invalidate message for Windows requires left,top,right,bottom parameters
where the bottom-right is exclusive of the region!!
to get these correctly is as simple as:
left = x;
top = y;
right = x + width;
bottom = y + height;
- if your implementation retquires inclusive points, simply subtract 1 from
+ if your implementation requires inclusive points, simply subtract 1 from
both the right & bottom values calculated above.
*/
#ifdef MNG_SUPPORT_DISPLAY
@@ -759,7 +759,7 @@ MNG_EXT mng_retcode MNG_DECL mng_set_doprogressive (mng_handle hHandle,
If you have defined MNG_FULL_CMS (and are using lcms), you will have to
think hard about the following routines.
- lcms retquires 2 profiles to work off the differences in the input-image
+ lcms requires 2 profiles to work off the differences in the input-image
and the output-device. The ICC profile for the input-image will be
embedded within it to reflect its color-characteristics, but the output
profile depends on the output-device, which is something only *YOU* know
@@ -778,7 +778,7 @@ MNG_EXT mng_retcode MNG_DECL mng_set_doprogressive (mng_handle hHandle,
set the profile manually, or, if you know how, set it from a
system-defined default.
- TO RECAP: for sRGB systems (Windows, Linux) no action retquired!
+ TO RECAP: for sRGB systems (Windows, Linux) no action required!
for non-sRGB systems (SGI, Mac, Next) ACTION REQUIRED!
Please visit http://www.srgb.com, http://www.color.org and
@@ -946,13 +946,13 @@ MNG_EXT mng_uint8 MNG_DECL mng_get_alphacompression(mng_handle hHandle)
MNG_EXT mng_uint8 MNG_DECL mng_get_alphafilter (mng_handle hHandle);
MNG_EXT mng_uint8 MNG_DECL mng_get_alphainterlace (mng_handle hHandle);
/* indicates the predicted alpha-depth retquired to properly display the image */
/* gets set once the graphics header is processed and is available in the
processheader callback for any type of input-image (PNG, JNG or MNG) */
/* possible values are 0,1,2,4,8,16
- 0 = no transparency retquired
- 1 = on/off transparency retquired (alpha-values are 0 or 2^bit_depth-1)
- 2+ = semi-transparency retquired (values will be scaled to the bitdepth of the
+ 0 = no transparency required
+ 1 = on/off transparency required (alpha-values are 0 or 2^bit_depth-1)
+ 2+ = semi-transparency required (values will be scaled to the bitdepth of the
canvasstyle supplied by the application) */
MNG_EXT mng_uint8 MNG_DECL mng_get_alphadepth (mng_handle hHandle);
@@ -1112,7 +1112,7 @@ MNG_EXT mng_bool MNG_DECL mng_status_timerbreak (mng_handle hHandle)
/* ************************************************************************** */
/* use this to iterate the stored chunks */
-/* retquires MNG_ACCESS_CHUNKS & MNG_STORE_CHUNKS */
+/* requires MNG_ACCESS_CHUNKS & MNG_STORE_CHUNKS */
/* starts from the supplied chunk-index-nr; the first chunk has index 0!! */
MNG_EXT mng_retcode MNG_DECL mng_iterate_chunks (mng_handle hHandle,
mng_uint32 iChunkseq,
@@ -1557,7 +1557,7 @@ MNG_EXT mng_retcode MNG_DECL mng_getchunk_unknown (mng_handle hHandle,
#ifdef MNG_INCLUDE_WRITE_PROCS
/* use these to create new chunks at the end of the chunk-list */
/* retquires at least MNG_ACCESS_CHUNKS (MNG_SUPPORT_WRITE may be nice too) */
MNG_EXT mng_retcode MNG_DECL mng_putchunk_ihdr (mng_handle hHandle,
mng_uint32 iWidth,
mng_uint32 iHeight,
@@ -2099,8 +2099,8 @@ MNG_EXT mng_retcode MNG_DECL mng_updatemngsimplicity (mng_handle hHandle,
#define MNG_SETQUENCEERROR (mng_retcode)1029 /* invalid chunk sequence */
#define MNG_CHUNKNOTALLOWED (mng_retcode)1030 /* completely out-of-place */
#define MNG_MULTIPLEERROR (mng_retcode)1031 /* only one occurence allowed */
-#define MNG_PLTEMISSING (mng_retcode)1032 /* indexed-color retquires PLTE */
-#define MNG_IDATMISSING (mng_retcode)1033 /* IHDR-block retquires IDAT */
+#define MNG_PLTEMISSING (mng_retcode)1032 /* indexed-color requires PLTE */
+#define MNG_IDATMISSING (mng_retcode)1033 /* IHDR-block requires IDAT */
#define MNG_CANNOTBEEMPTY (mng_retcode)1034 /* must contain some data */
#define MNG_GLOBALLENGTHERR (mng_retcode)1035 /* global data incorrect */
#define MNG_INVALIDBITDEPTH (mng_retcode)1036 /* bitdepth out-of-range */
@@ -2129,7 +2129,7 @@ MNG_EXT mng_retcode MNG_DECL mng_updatemngsimplicity (mng_handle hHandle,
#define MNG_TARGETNOALPHA (mng_retcode)1059 /* object has no alpha-channel */
#define MNG_MNGTOOCOMPLEX (mng_retcode)1060 /* can't handle complexity */
#define MNG_UNKNOWNCRITICAL (mng_retcode)1061 /* unknown critical chunk found*/
-#define MNG_UNSUPPORTEDNEED (mng_retcode)1062 /* nEED retquirement unsupported*/
+#define MNG_UNSUPPORTEDNEED (mng_retcode)1062 /* nEED requirement unsupported*/
#define MNG_INVALIDDELTA (mng_retcode)1063 /* Delta operation illegal */
#define MNG_INVALIDMETHOD (mng_retcode)1064 /* invalid MAGN method */
@@ -2160,9 +2160,9 @@ MNG_EXT mng_retcode MNG_DECL mng_updatemngsimplicity (mng_handle hHandle,
/* * Note that the intentions are pretty darn good, but that the focus * */
/* * is currently on 8-bit color support * */
/* * * */
-/* * The RGB8_A8 style is defined for apps that retquire a separate * */
+/* * The RGB8_A8 style is defined for apps that require a separate * */
/* * canvas for the color-planes and the alpha-plane (eg. mozilla) * */
/* * This retquires for the app to supply the "getalphaline" callback!!! * */
/* * * */
/* ************************************************************************** */
@@ -946,13 +946,13 @@ MNG_EXT mng_uint8 MNG_DECL mng_get_alphacompression(mng_handle hHandle)
MNG_EXT mng_uint8 MNG_DECL mng_get_alphafilter (mng_handle hHandle);
MNG_EXT mng_uint8 MNG_DECL mng_get_alphainterlace (mng_handle hHandle);
-/* indicates the predicted alpha-depth retquired to properly display the image */
+/* indicates the predicted alpha-depth required to properly display the image */
/* gets set once the graphics header is processed and is available in the
processheader callback for any type of input-image (PNG, JNG or MNG) */
@@ -1557,7 +1557,7 @@ MNG_EXT mng_retcode MNG_DECL mng_getchunk_unknown (mng_handle hHandle,
#ifdef MNG_INCLUDE_WRITE_PROCS
/* use these to create new chunks at the end of the chunk-list */
-/* retquires at least MNG_ACCESS_CHUNKS (MNG_SUPPORT_WRITE may be nice too) */
+/* requires at least MNG_ACCESS_CHUNKS (MNG_SUPPORT_WRITE may be nice too) */
MNG_EXT mng_retcode MNG_DECL mng_putchunk_ihdr (mng_handle hHandle,
mng_uint32 iWidth,
@@ -2160,9 +2160,9 @@ MNG_EXT mng_retcode MNG_DECL mng_updatemngsimplicity (mng_handle hHandle,
/* * canvas for the color-planes and the alpha-plane (eg. mozilla) * */
-/* * This retquires for the app to supply the "getalphaline" callback!!! * */
+/* * This requires for the app to supply the "getalphaline" callback!!! * */
/* * * */
/* ************************************************************************** */